@@ -1,5 +1,5 @@
 package Bio::ToolBox::parser::ucsc;
-our $VERSION = '1.65';
+our $VERSION = '1.69';
 
 =head1 NAME
 
@@ -1182,7 +1182,7 @@ sub new {
 	
 	# verify
 	my @errors; 
-	push @errors, 'strand'     unless $self{strand}     =~ /^[\+\-]$/;
+	push @errors, 'strand'     unless $self{strand}     =~ /^[\+\-\.]$/;
 	push @errors, 'txStart'    unless $self{txStart}    =~ /^\d+$/;
 	push @errors, 'txEnd'      unless $self{txEnd}      =~ /^\d+$/;
 	push @errors, 'cdsStart'   unless $self{cdsStart}   =~ /^\d+$/;
@@ -1196,7 +1196,7 @@ sub new {
 	}
 	
 	# fix values
-	$self{strand}     = $self{strand} eq '+' ? 1 : -1;
+	$self{strand}     = $self{strand} eq '+' ? 1 : $self{strand} eq '-' ? -1 : 0;
 	$self{exonStarts} = [ map {$_ += 1} ( split ",", $self{exonStarts} ) ];
 	$self{exonEnds}   = [ ( split ",", $self{exonEnds} ) ];
 	
