@@ -27,7 +27,7 @@ use constant DATASET_HASH_LIMIT => 4999;
 		# region, and a hash returned with potentially a score for each basepair. 
 		# This may become unwieldy for very large regions, which may be better 
 		# served by separate database queries for each window.
-my $VERSION = '1.68';
+my $VERSION = 'v1.691';
 
 print "\n A script to collect windowed data flanking a relative position of a feature\n\n";
   
@@ -723,11 +723,7 @@ sub map_relative_long_data {
 	while (my $row = $stream->next_row) {
 		
 		# calculate a reference point using an internal feature method
-		my $args = {
-			position => $position
-		};
-		$row->_calculate_reference($args);
-		my $reference = $args->{coordinate};
+		my $reference = $row->calculate_reference($position);
 		
 		# collect the data for every window 
 		for (
@@ -745,8 +741,8 @@ sub map_relative_long_data {
 									$reference + $Data->metadata($column, 'start') :
 									$reference - $Data->metadata($column, 'start'),
 				'stop'        => $row->strand >= 0 ? 
-									$row + $Data->metadata($column, 'stop') : 
-									$row - $Data->metadata($column, 'stop'),
+									$reference + $Data->metadata($column, 'stop') : 
+									$reference - $Data->metadata($column, 'stop'),
 				'strand'      => $row->strand,
 				'method'      => $method,
 				'stranded'    => $strand_sense,
